aboutsummaryrefslogtreecommitdiffstats
path: root/java/src
diff options
context:
space:
mode:
authorYuichiro Hanada <yhanada@google.com>2013-10-18 20:20:46 +0900
committerYuichiro Hanada <yhanada@google.com>2013-10-18 20:28:07 +0900
commit52f18d7f40de9b3afac089e441346fb465b5ab49 (patch)
tree221c408096c456e83203eb96e256ab007b41f0f9 /java/src
parent8e9af925b1b29b64471795a2c1188b5af9c21746 (diff)
downloadlatinime-52f18d7f40de9b3afac089e441346fb465b5ab49.tar.gz
latinime-52f18d7f40de9b3afac089e441346fb465b5ab49.tar.xz
latinime-52f18d7f40de9b3afac089e441346fb465b5ab49.zip
Change the block sizes for SparseTables.
This change saves about 240k bytes. Bug: 10941472 Change-Id: Ieb00e4dd3391cdb0d42d705f8d0a7b1421f516f9
Diffstat (limited to 'java/src')
-rw-r--r--java/src/com/android/inputmethod/latin/makedict/FormatSpec.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/java/src/com/android/inputmethod/latin/makedict/FormatSpec.java b/java/src/com/android/inputmethod/latin/makedict/FormatSpec.java
index 6d5827023..b99aca2c8 100644
--- a/java/src/com/android/inputmethod/latin/makedict/FormatSpec.java
+++ b/java/src/com/android/inputmethod/latin/makedict/FormatSpec.java
@@ -278,9 +278,9 @@ public final class FormatSpec {
static final int UNIGRAM_TIMESTAMP_SIZE = 4;
// With the English main dictionary as of October 2013, the size of bigram address table is
- // is 584KB with the block size being 4.
- // This is 91% of that of full address table.
- static final int BIGRAM_ADDRESS_TABLE_BLOCK_SIZE = 4;
+ // is 345KB with the block size being 16.
+ // This is 54% of that of full address table.
+ static final int BIGRAM_ADDRESS_TABLE_BLOCK_SIZE = 16;
static final int BIGRAM_CONTENT_COUNT = 2;
static final int BIGRAM_FREQ_CONTENT_INDEX = 0;
static final int BIGRAM_TIMESTAMP_CONTENT_INDEX = 1;
@@ -293,7 +293,7 @@ public final class FormatSpec {
static final int SHORTCUT_CONTENT_COUNT = 1;
static final int SHORTCUT_CONTENT_INDEX = 0;
// With the English main dictionary as of October 2013, the size of shortcut address table is
- // 29KB with the block size being 64.
+ // 26KB with the block size being 64.
// This is only 4.4% of that of full address table.
static final int SHORTCUT_ADDRESS_TABLE_BLOCK_SIZE = 64;
static final String SHORTCUT_CONTENT_ID = "_shortcut";